models

package
v0.0.0-...-d0b32f8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2021 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

const (
	// Bare metal plugin type.
	Bare = "bare"
	// Container plugin type.
	Container = "container"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BareMetalPlugin

type BareMetalPlugin struct {
	Location string
}

BareMetalPlugin is a plugin which is a file on the filesystem.

type ContainerPlugin

type ContainerPlugin struct {
	Image string
}

ContainerPlugin is a specific plugin which is in a container.

type Plugin

type Plugin struct {
	ID        int
	Name      string
	Type      string
	Container *ContainerPlugin
	Bare      *BareMetalPlugin
}

Plugin defines what a Plugin looks like.

Jump to