Documentation
¶
Index ¶
Constants ¶
const ( // Bare metal plugin type. Bare = "bare" // Container plugin type. Container = "container" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BareMetalPlugin ¶
type BareMetalPlugin struct {
Location string
}
BareMetalPlugin is a plugin which is a file on the filesystem.
type ContainerPlugin ¶
type ContainerPlugin struct {
Image string
}
ContainerPlugin is a specific plugin which is in a container.
type Plugin ¶
type Plugin struct {
ID int
Name string
Type string
Container *ContainerPlugin
Bare *BareMetalPlugin
}
Plugin defines what a Plugin looks like.
Click to show internal directories.
Click to hide internal directories.